Changelog
=========

Versions follow `CalVer <http://calver.org>`_ with a strict backwards compatibility policy.
The third digit is only for regressions.


17.1.0 (2017-12-14)
-------------------

Initial release.


----
